#
# spec file for package starship
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           starship
Version:        1.16.0
Release:        1.3
Summary:        A customizable prompt for many shells
License:        ISC
URL:            https://starship.rs/
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.zst
Source2:        cargo_config
BuildRequires:  cargo-packaging
BuildRequires:  cmake
BuildRequires:  pkgconfig(openssl)

%description
Starship generates shell code which modifies the current shell
behavior to display an extravagant prompt. It installs a hook before
every command invocation to gather additional information for the
prompt, which increases the latency of the prompt (by about 5 ms with
bash on a contemporary 3700X CPU).
The default setup requires Nerd Font and a terminal in dark colors.
dash is not supported as of 1.10.2.

%prep
%autosetup -a1
mkdir -p .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

%files
%doc README.md
%license LICENSE
%{_bindir}/starship

%changelog
* Mon Jul 31 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.16.0:
  * Features:
  - pwsh: Support vi command mode indicator.
  - shlvl: add repeat_offset for repeated symbol.
  - update the nushell init file and make it valid module
    and overlay.
  * Bug Fixes:
  - bash: Clear out completed jobs before counting NUM_JOBS.
  - rprompt: remove lprompt modules from $all again.
  * Performance Improvements:
  - git_status: query git stash count via gitoxide.
* Tue Jun  6 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.15.0:
  * Features:
  - Add Solidity Module.
  - add typechange to git_status module.
  - aws: support aws sso with automatic authentication refresh.
  - azure: subscription name aliases.
  - gcloud: add detect_env_vars option.
  - git_metrics: add option to ignore submodules.
  - golang: adding mod_version variable.
  - nodejs: Add expected_version variable.
  * Bug Fixes:
  - config: Make print-config not panic without a config.
  - ensure nested style variables are processed during formatting.
  - presets: Added ($style) to format in module 'sudo'
    in Bracketed Segments Preset.
  - style: ensure nested style variables are processed during
    formatting.
  - update of presets and default configuration to reflect
    changes in Nerd Fonts 3.0.
* Fri Apr 14 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.14.2:
  * git_commit: resolve panic on 32-bit targets.
* Tue Apr 11 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.14.1:
  * Features:
  - aws: add support for source_profile.
  - aws: Adds support for AWS_CREDENTIAL_EXPIRATION
    environment variable.
  - custom: add option to check if pwd is in a repo.
  - fossil: detection of Fossil check-outs in subdirectories.
  * Bug Fixes:
  - gradle: add support for unstable Gradle versions.
  - init: avoid cygpath for starship binary path.
  - java: wrong version number when using Android Studio JDK.
  - preset: add output-flag to avoid encoding issues.
  - pulumi: Fix formatting on pulumi module when using version.
* Mon Feb 27 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.13.1:
  * Features:
  - config: Adds support for --profile <custom profile name>.
  - env_var: Add support for env_var.VAR in format.
  - fennel: add fennel module.
  - add pijul_channel module.
  - fossil_branch: add fossil_branch module.
  - gradle: add gradle module.
  - hg_branch: Add support for mercurial topics and find hg
    root dir.
  - java: Add .sdkmanrc for Java.
  - logger: delete old logs & avoid more dup logs.
  * Bug Fixes:
  - 'to to' -> 'to'.
  - container: reduce docker, podman and systemd confusion.
  - fish: enable transient prompt when in vi mode.
  - git_commit: fix potential test failure.
  - Improve regex for extracting gradle package version from
    gradle.properties.
  - let-env warning when using nushell.
  - nodejs: apply style even if node version is unavailable
  - package: Improve regex for extracting gradle version
    from gradle.properties.
* Sun Dec 18 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.12.0:
  * Features:
  - add Haxe support
  - Add operating system module
  - aws: add a fallback for expiration key
  - azure: add username to azure module config
  - bug-report: ask for confirmation before opening issue
  - directory: add before_repo_root_style
  - git_commit: support showing lightweight tags
  - guix_shell: Initial implementation
  - init: Use which-rs to resolve starship path
  - localip: use reserved remote address
  - nu: enable right prompt
  - Open Policy Agent module
  - package: added showing gradle version based on the gradle.properties file
  - preset: Add No Empty Icons preset
  - preset: Add no-nerd-font preset
  - release: add chocolatey publishing
  * Bug Fixes:
  - aws: enable when using .aws/credentials
  - buf: broken icon on windows 10
  - ci: cache after selecting the toolchain
  - config: unrecognized config properties don't cause config error
  - container: avoid detecting WSL as a systemd-container
  - don't attempt to display cmd_duration notification if in TTY
  - git: check tag_disabled option
  - java: Improved regex for Java version
  - nu: remove -c parameter from term size
  - pwsh: fix error log display on older versions of pwsh
  - status: replace multiply with cross mark emoji
* Sun Oct 16 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.11.0:
  * add user-defined color palette.
  * fish: Enable left and right transience.
  * module: Add a meson devenv indicator.
  * schema: deny unknown keys.
  * status: Support formatting of pipestatus separator.
  * buf: fix spacing & harmonize docs with actual configuration.
  * directory: don't strip duplicate directory names twice.
  * pwsh: avoid potential deadlock in init.
  * directory: Skip repo resolution if unused by directory config.
* Fri Sep  9 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.10.3:
  * git_commit: only use exact match for tag by default.
* Thu Aug 25 2022 Dead Mozay <dead_mozay@opensuse.org>
- Use setup instead of autosetup.
* Thu Aug 25 2022 Jan Engelhardt <jengelh@inai.de>
- Remove nondescript claims from description
* Fri Aug 19 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.10.2:
  * No changelog was made available.
* Tue Aug 16 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.10.1:
  * Disable multithreading in jwalk (via gitoxide) as workaround
    for #4251 (#4258) (37b54f7).
* Mon Aug 15 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.10.0:
  * add bun module.
  * Add starship preset command.
  * Add support for blink, hidden, and strikethrough styles.
  * Add the ability to have some file extensions prevent a module
    from triggering.
  * k8s: Add folder detection to the k8s module.
  * package: support cargo workspace versions.
  * status: Add pipestatus_segment_format option to status module.
  * aws: support official AWS_SHARED_CREDENTIALS_FILE variable.
  * timings: count time spent on custom on 'when' command failure.
  * pulumi: allow disabling upwards discovery.
* Fri Jul  8 2022 William Brown <william.brown@suse.com>
- Remove dependency on unmaintained rust-packaging
* Tue Jun 28 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.9.1:
  * add Raku module.
  * character: Standadise Vim config names.
  * Removed strip binary.
* Wed Jun 22 2022 Dead Mozay <dead_mozay@opensuse.org>
- Fix W: unstripped-binary-or-object.
* Thu Jun 16 2022 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 1.8.0:
  * Add support for Daml.
  * kubernetes: add user alias.
  * escape text segments in meta variables.
  * fish: add proper vi mode detection for fish shell.
  * install: ignore tarfile ownership values when installing as root.
  * nu: don't use cygpath for starship binary path in init.
* Wed May 25 2022 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 1.7.1:
  * go: check for go.work file to show Go module in prompt.
  * hostname: add ssh_symbol for ssh connections.
  * package: Extract package version from PEP 621
    compliant pyproject.toml.
  * rust: Display toolchain names.
  * Do not panic in config if editor not found.
  * module: list option not working.
  * nu: use the most recent starship init.
  * Use git2::Repository::open_ext() instead of discover().
* Wed Apr 27 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.6.3:
  * git_branch: correct variable name for remote branch.
* Sat Apr 16 2022 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 1.6.2:
  * Add a module for C projects.
  * allow printing config file schema.
  * aws: add option to force AWS display.
  * cmd_duration: make notify feature optional (compat with nix darwin).
  * spack: Add Spack module.
  * bash: ensure checkwinsize is enabled for $COLUMNS
  * directory: enable repo_root_style when truncation_length is zero.
  * docker_context: ignore the "default" context.
  * fish: allow generating session keys in older versions of fish.
  * init: Change Elvish init to catch for 0.18.
  * nu: Use = instead of space to pass command line parameters.
  * nu: use shell-provided terminal width.
* Fri Mar 25 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.5.4:
  * aws: Add profile aliases.
  * buf: Add Buf module.
  * git_branch: add 'ignore_branches' option.
  * haskell: Add Haskell module.
  * nodejs: check for .mts and .cts files.
  * aws: accept sso credentials.
  * aws: Make AWS_REGION orverrides AWS_DEFAULT_REGION.
  * docs: fix and cleanup VuePress config.
  * init: Change Nushell init for nu 0.60.
  * status: Make status module work even when the status is 0.
* Fri Mar 11 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.4.2:
  * No changelog available.
* Wed Mar  9 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.4.0:
  * Exclude vuepress output from dprint.
  * ignore empty --jobs argument.
  * aws: Only display AWS if there are credentials configured.
  * fish: Emit clear-screen escape sequence only in left prompt.
  * localip: disable localip module default.
  * pwsh: Use global:error[0] for most recent error in powershell.
* Mon Feb  7 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.3.0:
  * add username to Pulumi module.
  * Enable Undistract Me for Linux.
  * starship bug-report sets syntax highlighting for config file.
  * add a container indicator.
  * cli: Print arguments if argument parsing fails.
  * cmd_duration: Make notification timeout configurable.
  * install: Add posix shell check.
  * localip: add module to print the current ipv4 address.
  * pwsh: Set ExtraPromptLineCount.
  * pwsh: Set STARSHIP_SHELL to pwsh on PS >5.
  * Correctly detect older versions of powershell in bug-report.
  * bash: Restore previous exit status in bash init.
  * elvish: use $pwd for logical-path.
  * nodejs: use e718 as the default of symbol in node configuration.
  * status: Enable to convert from i64 to hex_status by casting
    instead of parsing status.
  * Improve compatibility with Zsh prompt theme system.
  * zsh: using add-zsh-hook instead of add hook manually.
  * elvish: Use built-in randint instead of starship session.
* Sat Jan 15 2022 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 1.2.1:
  * properties: fix regressions in status, pipestatus
    and terminal-width handling.
  * pwsh: Avoid polluting the global function namespace.
* Fri Jan 14 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.2.0:
  * No changelog available.
* Wed Dec 22 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 1.1.1:
  * Add package version detection for sbt projects.
  * print-config subset of config.
  * azure: Azure module.
  * module: Add sudo module.
  * status: Add hex_status.
  * Display durations of 0ms.
  * Store $? and $LASTEXITCODE first in PowerShell.
  * aws: prevent endless loop when AWS config file is a directory.
  * directory: improve truncation detection.
  * docs: remove superfluous space.
  * git_branch: more robust handling of .git.
* Fri Nov 26 2021 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 1.0.0:
  * Add starship_precmd_user_func support for PowerShell.
  * style git repo root.
  * Add pulumi module.
  * also read from DOCKER_MACHINE_NAME.
  * docs: Add copy button for code snippets via plugin.
  * explain: allow specifying prompt arguments in explain and
    timings subcommands.
  * fill: add disabled option for fill module.
  * package: Add support for crystal shards.
  * python: Show value of PYENV_VERSION when present.
  * ruby: Add environment variable checks to ruby module.
  * shell: Add style config for shell module.
  * Modules not working in fish RPROMPT.
  * replace battery with starship-battery.
  * pipestatus quoting on Zsh/Bash.
  * allow unset KEYMAP and STARSHIP_DURATION in zsh.
  * ignore scan_dir timeout in tests.
  * init script line endings.
  * only print root level config logs a single time.
  * save pipestatus in fish init functions.
  * configure: preserve formatting and comments.
  * escaping: move escaping to individual variables.
  * fill: Add terminal-width argument to explicitly define
    terminal's width.
  * init: Use stderr for init error message.
  * memory_usage: remove duplicate %% handling.
  * status: Don't show status if all exit codes are 0.
  * terraform: Improve module triggers.
  * replace term_size with terminal_size.
* Wed Sep 22 2021 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 0.58.0:
  * Add a fill module to pad out the line.
  * Add support for RPROMPT (right prompt).
  * cobol: added COBOL module.
  * git_metrics: Git metrics show only nonzero diffs.
  * print-config: list expanded $all variable.
  * config: inherit stdin/stdout/stderr instead of piping to fix editor invocation.
  * package: Ignore setup.cfg attr: and file:.
  * print-config: add missing format_right to FullConfig.
  * zsh: always escape percent character.
  * zsh init script: avoid adding preexec commands twice.
* Thu Aug 26 2021 Dead Mozay <dead-mozay@opensuse.org>
- Update to version 0.57.0:
  * clippy: fix new clippy lints.
  * git_status: show working tree status if index status is present.
  * init: remove quotes in bash init.
  * jobs: Add the symbol and number thresholds respecting the threshold option.
  * print-config: fix battery module and add missing modules.
  * add support for xonsh.
  * git_status: dont render module output if not in git repository.
  * git_status: added symbol for local repos up-to-date with remote.
  * kubernetes: implements regex matching for context aliases.
  * package: Add ability to format the version.
  * package: Support package version from setup.cfg (python).
  * status: Add pipestatus display in status module.
* Wed Jul 14 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.56.0:
  * clippy: fix additional clippy lints in tests.
  * dotnet: make default format consistent with other module.
  * git_status: Fix when the worktree != root dir.
  * init: improve starship path escaping.
  * nu: use correct session key variable name.
  * pwsh: replace Get-Error with $error[0].
  * rust: support for rust-toolchain.toml.
  * Add the git_metrics module.
  * add support for nu shell.
  * treat empty string as none when formating.
  * docker_context: Use DOCKER_HOST and DOCKER_CONTEXT enviroment variables.
  * env_var: allow multiple instances.
  * Improve custom config OS.
  * enforce ALL_MODULES ordering in test.
  * fix name of battery info provider implementation.
* Mon Jun 21 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.55.0:
  * remove trailing whitespace from Terraform version.
  * clippy: fix new lint warning
  * dotnet: Don't treat folder with .sln file as a .NET project.
  * Add Operating System condition to custom commands.
  * r-lang: add module for R programming language.
* Sun May 16 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.54.0:
  * add missing project filter rules.
  * git_commit: leading space in git commit tag.
  * git_status: Show git add -N files as unstaged.
  * zsh: preserve zle-keymap-select.
* Sun May  2 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.53.0:
  * configure: fix launching .cmd editors
  * fish: explicitly set scope in fish init script
  * gcloud: add double space after cloud emoji symbol
  * init: always use lf line endings
  * print-config: add red module to Default impl
  * print-config: use proper defaults for top-level values
  * zsh: Reverts changes to background jobs retaining improvements
    around START_TIME
* Thu Apr 22 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.52.1:
  * fix docker_context module name in nf preset
  * Add a missing ' ' to the end of the python prompt
  * context: remove unwrap when pwd is unavailable
  * elixir: correctly parse dev and rc versions
  * git_branch: Make Git branch module support bare repositories
  * jobs: Handle zero jobs with zero thresholds
  * nodejs: Check for .nvmrc
  * shell: Support conditional format strings for $indicator
  * vcsh: Add new module for VCSH
  * git_status: replace git2 in git status module with git cli
  * battery: add space between icon and text for better visual
  * directory: Add comments for test settings
  * init: Cleanup the unknown shell message
* Wed Mar 24 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.51.0:
  * correct fish syntax error when setting variables.
  * Add a fallback prompt under TERM=dumb.
  * bash: escape interpretable characters.
  * cmake: Change cmake symbol to unicode triangle.
  * directory: contract git repo with display path.
  * directory: Handle non-UTF-8 folder names.
  * docs: "Command Duration" section link target.
  * init: Quote path for elvish init.
  * init: make log messages on pwsh visible again.
  * java: use consistent separators for java path.
  * nodejs: Change symbol to nerd-font.
  * package: fix meson version extraction if 'meson_version' is present.
  * python: Handle PyPy python version correctly.
  * tcsh: remove quotes and escape backticks.
  * utils: Sefely unwrap the command output.
  * zsh: Set PROMPT just once.
  * allow changing default command timeout.
  * create shell module.
  * add support for tcsh.
  * aws: add support for getting profile from awsu.
  * cmake: Configure when the module is shown.
  * crystal: Configure when the module is shown.
  * dart: Configure when the module is shown.
  * docker_context: Configure when module is shown.
  * dotnet: Configure when module is shown.
  * elixir: Configure when module is shown.
  * elm: Configure when the module is shown.
  * erlang: Configure when the module is shown.
  * golang: Configure when the module is shown.
  * helm: Configure when the module is shown.
  * install: make install script posix compliant.
  * java: Configure when the module is shown.
  * julia: Configure when the module is shown.
  * kotlin: Configure when the module is shown.
  * lua: Configure when the module is shown.
  * nim: Configure when the module is shown.
  * nodejs: Configure when the module is shown.
  * ocaml: Configure when the module is shown.
  * perl: Configure when the module is shown.
  * php: Configure when the module is shown.
  * purescript: Configure when the module is shown.
  * python: Configure when the module is shown.
  * ruby: Configure when the module is shown.
  * scala: Add scala module.
  * swift: Configure when the module is shown.
  * terraform: Configure when the module is shown.
  * test: allow dynamic mocking of commands.
  * vagrant: Configure when the module is shown.
  * zig: Configure when the module is shown.
  * init: Prefer set -x over export for fish users.
  * username: get uid without external command.
  * aws: Add spacing between profile and region.
* Wed Feb  3 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.50.0:
  * add support for elvish shell
  * vagrant: Add support for Vagrant
* Mon Feb  1 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.49.0:
  * Adjust default format strings
  * Applied clippy warnings
  * bash: Fix broken bash init script
  * bash: bash-preexec detection and implementation
  * cmake: Fix spacing with missing variable
  * docker_context: enable if either yml or yaml is found
  * command: add 'toggle' command
  * directory: Add home directory symbol
  * status: Convert known status code to their meaning
* Sun Jan  3 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.48.0:
  * apply nightly clippy & fmt suggestions
  * bg:none overwrites foreground colour
  * bash: Fix background jobs with z/autojump
  * config: log as error if failure to read config wasn't caused by NotFound
  * git_commit: show last created tag on current commit
  * git_state: Handle gitdir indirection when rebasing
  * swift: parsing swift version
  * i18n: add French and Spanish doc translations
  * battery: make module behaviour more obvious
  * git_branch: show remote name
  * git_branch: add remote branch name if different than local branch
  * git_branch: add 'only_attached' config bool
  * init: prefix STATUS and PREEXEC_READY shell vars with STARSHIP_
  * java: Show Java module for Clojure projects
  * kotlin: Add the kotlin module
  * nodejs: check node engines version in package.json
  * package: Meson package support
  * python: Smarter python binary usage
  * rust: Support new rust-toolchain format
  * shlvl: Add repeat option
  * username: Try harder to guess if inside ssh
  * memory_usage: replace sysinfo with sys-info
  * Latest clippy suggestions
  * Add comments for bash preexec fix
* Sun Nov 15 2020 dead_mozay@opensuse.org
- Update to version 0.47.0:
  * docs: Alphabetic sorting of config subsections (#1877)
  * feat(terraform): Add hcl extension support to Terraform
    module (#1875)
  * fix(pwsh): fix crash on error in shell with old pwsh (#1861)
  * perf(init/pwsh): use get-random for session-key instead of
    invoking starship session (#1860)
  * perf(init): use $RANDOM env-var instead of starship session
    to generate session-key (#1755)
  * fix(gcloud): respect overides of the active gcloud
    config (#1846)
  * docs(cmd_duration): Document cmd_duration
    notifications (#1831)
  * docs(pwsh/init): various fixes for init doc (#1793)
  * fix(bug-report): verify exit code of open, always
    print url (#1839)
  * feat(lua): Add a Lua module (#1815)
  * fix(zsh): Ensure existing keymap change functions are not
    overriden (#1826)
  * feat(logger): don't create empty log files (#1836)
  * fix(install): Better platform detection (#1827)
  * feat(openstack): Add module for OpenStack (#1664)
  * fix(pwsh): Switched pwsh profile to use dollar hook for a more
    accurate success/failure handling  (#1745)
  * feat(git_commit): add git tag to module (#950)
  * fix(kubernetes): Parse stacked kubeconfigs (#1678)
  * fix(pwsh): preserve original console encondings (#1810)
  * docs(memory): Remove removed options from Memory example (#1800)
* Thu Oct 15 2020 dead_mozay@opensuse.org
- Update to version 0.46.2:
  * docs: Update document for installing on windows (#1760)
  * fix: replace emoji for cmake and erlang (#1787)
  * fix(directory): preserve substitution order (#1782)
  * fix: apply clippy suggestions (#1756)
  * docs: Update defaults in config docs (#1759)
* Fri Oct  9 2020 dead_mozay@opensuse.org
- Update to version 0.46.0:
  * fix(python): Read venv prompt from pyvenv.cfg (#1747)
  * docs(python): Update the python_binary option (#1731)
  * docs(FAQ): add FAQ about shell completions
  * feat(directory): add ellipsis to truncated paths (#1563)
  * fix(utils): reduce log level of errors in utils. (#1730)
  * fix(bug-report): use correct path for ion config (#1726)
* Thu Oct  1 2020 dead_mozay@opensuse.org
- Update to version 0.45.2:
  * No changelog.
* Wed Sep 30 2020 dead_mozay@opensuse.org
- Update to version 0.45.0:
  * Bug Fixes
  - bash: init breaks if PROMPT_COMMAND includes starship_precmd
    as an intermediate command (#1541)
  - config: don't panic when hex color is too short (#1473)
  - docs: Fix Explore The Starship link in guide (#1553)
  - explain: align table correctly (#1482)
  - git-state: Fix discrepancy between v0.44.0 and master (#1672)
  - git_state: panic on interactive rebase (#1552)
  - git_status: Fix file rename inconsistency compared to git (#1411)
  - install: switch to install the musl binaries by default (#1590)
  - nodejs: remove line break from version (#1464)
  - ocaml: Stop new line being included in ocaml version (#1479)
  - pwsh: update init script to propagate $LASTEXITCODE and $?
  - pwsh: stop paths from being interpreted as patterns (#1569)
  - zsh: work when setopt ksh_arrays is set (#1612)
  * Docs
  - Update example config to remove old var (#1546)
  - add a migration guide for the format string changes (#1624)
  - update clippy command in the CONTRIBUTING.md (#1665)
  - Improvements in docs for custom modules (#1615)
  - Drop inexistent "number" variable from hostname section (#1586)
  - Add perl official logo in NerdFont (#1558)
  - fix code block overflow on mobile (#1492)
  - add uninstallation instructions to FAQ (#1474)
  - update font in FAQ from Fira Code → FiraCode Nerd Font
  - replace powerline requirement with nerd font requirement
  - git_status: Update git_status module docs (#1667)
  - i18n: New Crowdin translations (#1366)
* Tue Jul  7 2020 dead_mozay@opensuse.org
- Update to version 0.44.0:
  * No chengelog.
* Sat Jun 27 2020 dead_mozay@opensuse.org
- Update to version 0.43.0:
  * Bug Fixes
  - errant space breaks tar in installer (#1314)
  - bash: last command status and command duration (#1185)
  - directory: Fix path contractions for symlinked git repos (#1299)
  - php: Stop including error messages in the version
  * Docs
  - update dotfile link in FAQ
  - instruct users to install a nerd-font (#1383)
  - Add FAQ entry on missing symbols (#1307)
  - remove redundant settings in Contributing guide (#1326)
  * Features
  - dotnet: adds additional files to detect .net projects (#1303)
  - git: honor GIT_DIR environment variable (#1348)
  - nodejs: support additional file patterns (#1311)
  - python: Add option to change the python binary (#1297)
* Wed Jun 10 2020 dead_mozay@opensuse.org
- Update to version 0.42.0:
  * Bug Fixes
  - Retain previous command state on zsh keymap select (#958)
  - custom: improve handling of Powershell prompts (#1237)
  * Docs
  - Updated config with a tip for PowerShell user (#1216)
  - fix example Starship implementation in bash
  - custom: add warning about custom command potentially freezing
    terminal (#1242)
* Sat May 16 2020 dead_mozay@opensuse.org
- Update to version 0.41.3:
  * No chengelog.
* Fri May 15 2020 dead_mozay@opensuse.org
- Update to version v0.41.1:
  * Bug Fixes
  - directory: avoid confusing modules with PowerShell paths (#1114)
  * Docs
  - correct the configuration docs (#1195)
  - i18n: new Crowdin translations (#1059)
* Wed Apr 29 2020 dead_mozay@opensuse.org
- Update to version v0.41.0:
  * Revert
  - fix(git_branch,git_status): implement fallback branch_n… (#1092)
* Mon Apr 13 2020 dead_mozay@opensuse.org
- Update to version v0.40.1:
  * Bug Fixes
  - Fix variable styles in string formatter (#1069)
  - implement fallback branch_name for bare git repos (#1035)
  - Fix typo (#1054)
  - ruby: do not assume length when retrieving version
  * Docs
  - Add details about musl build to readme (#997)
  - update NerdFont preset to include new modules (#1077)
  - add Open Collective to README
  - i18n: new Crowdin translations (#1047)
  * Features
  - add support for custom modules
  - nix_shell: add symbol to nix-shell module (#1058)
  - package: Add project version for Elixir (#1067)
  * Improvement
  - add parser for format strings (#1021)
* Mon Apr 13 2020 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
